@@ -155,7 +155,7 @@ struct node *m_defs;	/* profile/context structure  */
 /*
  * This is the program to process MIME composition files
  */
-char *buildmimeproc = nmhbindir (/mhn);
+char *buildmimeproc = nmhbindir (/mhbuild);
 /*
  * This is the program to `cat' a file.
  */
@@ -190,7 +190,9 @@ char *installproc = nmhlibdir (/install-mh);
 
 /*
  * This is the default program invoked by a "list" response
- * at the "What now?" prompt.
+ * at the "What now?" prompt.  It is also used by the draft
+ * folder facility in comp/dist/forw/repl to display the
+ * draft message.
  */
 
 char *lproc = DEFAULT_PAGER;
@@ -202,13 +204,20 @@ char *lproc = DEFAULT_PAGER;
 char *mailproc = nmhbindir (/mhmail);
 
 /*
- * mhl runs this program as a front-end.
+ * This is used by mhl as a front-end.  It is also used
+ * by mhn as the default method of displaying message bodies
+ * or message parts of type text/plain.
  */
 
 char *moreproc = DEFAULT_PAGER;
 
 /* 
- * This program is mhl - the nifty message lister
+ * This is the program (mhl) used to filter messages.  It is
+ * used by mhn to filter and display the message headers of
+ * MIME messages.  It is used by repl/forw (with -filter)
+ * to filter the message to which you are replying/forwarding.
+ * It is used by send/post (with -filter) to filter the message
+ * for "Bcc:" recipients.
  */
 
 char *mhlproc = nmhlibdir (/mhl);
@@ -262,18 +271,19 @@ char *sendproc = nmhbindir (/send);
 
 /*
  * This is the path to the program used by "show"
- * to display MIME messages.
+ * to display non-text (MIME) messages.
  */
 
 char *showmimeproc = nmhbindir (/mhn);
 
 /*
- * This is the default program called by "show" to display
- * text (non-MIME) messages.  By setting showproc to mhl,
- * the user can run mhl instead.
+ * This is the default program called by "show" to filter
+ * and display standard text (non-MIME) messages.  It can be
+ * changed to a pager (such as "more" or "less") if you prefer
+ * that such message not be filtered in any way.
  */
 
-char *showproc = DEFAULT_PAGER;
+char *showproc = nmhlibdir (/mhl);
 
 /* 
  * This program is called by vmh as the back-end to the window management
