@@ -198,20 +198,18 @@ getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
     }
 
     if (wanthost == AD_NHST)
-	mp->m_type = uleq (LocalName (), mp->m_host)
+	mp->m_type = !strcasecmp (LocalName (), mp->m_host)
 	    ? LOCALHOST : NETHOST;
 #ifdef DUMB
     else
-	mp->m_type = uleq (LocalName (), mp->m_host) ? LOCALHOST
-		: NETHOST;
+	mp->m_type = strcasecmp (LocalName(), mp->m_host) ?  NETHOST : LOCALHOST;
 #else /* not DUMB */
     else
 	if (pp = OfficialName (mp->m_host)) {
     got_real_host: ;
 	    free (mp->m_host);
 	    mp->m_host = getcpy (pp);
-	    mp->m_type = uleq (LocalName (), mp->m_host) ? LOCALHOST
-		    : NETHOST;
+	    mp->m_type = strcasecmp (LocalName(), mp->m_host) ? NETHOST : LOCALHOST;
 	}
 	else {
 	    if (dp = strchr(mp->m_host, '.')) {
@@ -420,11 +418,11 @@ ismymbox (struct mailname *np)
 	    goto local_test;
 
 	case UUCPHOST:
-	    if (!uleq (np->m_host, SystemName ()))
+	    if (strcasecmp (np->m_host, SystemName()))
 		break;		/* fall */
 	case LOCALHOST:
 local_test: ;
-	    if (uleq (np->m_mbox, mq.m_mbox))
+	    if (!strcasecmp (np->m_mbox, mq.m_mbox))
 		return 1;
 	    break;
 
@@ -445,11 +443,11 @@ local_test: ;
 	    continue;
 	switch (mp->m_type & W_MBOX) {
 	    case W_NIL: 
-		if (!uleq (cp, pp))
+		if (strcasecmp (cp, pp))
 		    continue;
 		break;
 	    case W_MBEG: 
-		if (!uleq (cp + len - i, pp))
+		if (strcasecmp (cp + len - i, pp))
 		    continue;
 		break;
 	    case W_MEND: 
@@ -471,11 +469,11 @@ local_test: ;
 	    continue;
 	switch (mp->m_type & W_HOST) {
 	    case W_NIL: 
-		if (!uleq (cp, pp))
+		if (strcasecmp (cp, pp))
 		    continue;
 		break;
 	    case W_HBEG: 
-		if (!uleq (cp + len - i, pp))
+		if (strcasecmp (cp + len - i, pp))
 		    continue;
 		break;
 	    case W_HEND: 
