@@ -1,12 +1,12 @@
 
 /*
- * concat.c - concatenate a variable number (minimum of 1)
- *            of strings in managed memory
+ * concat.c -- concatenate a variable number (minimum of 1)
+ *             of strings in managed memory
  *
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 char *
