@@ -19,7 +19,7 @@ context_del (char *key)
 
     context_read();
     for (np = m_defs, pp = NULL; np; pp = np, np = np->n_next) {
-	if (uleq (np->n_name, key)) {
+	if (!strcasecmp (np->n_name, key)) {
 	    if (!np->n_context)
 		admonish (NULL, "bug: context_del(key=\"%s\")", np->n_name);
 	    if (pp)
