@@ -10,8 +10,9 @@
 char *
 copy(char *from, char *to)
 {
-    while (*to++ = *from++)
-	continue;
-
-    return (to - 1);
+    while ((*to = *from)) {
+	to++;
+	from++;
+    }
+    return (to);
 }
