@@ -13,7 +13,7 @@ copyip (char **p, char **q)
 {
     while (*p)
 	*q++ = *p++;
-    *q = 0;
+    *q = NULL;
 
     return q;
 }
