@@ -38,8 +38,8 @@ static int get_x400_comp (char *, char *, char *);
 static int
 match (char *str, char *sub)
 {
-    register int c1, c2;
-    register char *s1, *s2;
+    int c1, c2;
+    char *s1, *s2;
 
 #ifdef LOCALE
     while ((c1 = *sub)) {
@@ -70,7 +70,9 @@ match (char *str, char *sub)
     return 1;
 }
 
-/* macros to format data */
+/*
+ * macros to format data
+ */
 
 #define PUTDF(cp, num, wid, fill) if (cp + wid < ep){\
 		if((i = (num))<0) i = -(num);\
@@ -88,6 +90,7 @@ match (char *str, char *sub)
 		    *--sp = fill;\
 		cp += c;\
 		}
+
 #define PUTD(cp, num) if (cp < ep){\
 		if((i = (num))==0) *cp++ = '0';\
 		else {\
@@ -103,6 +106,7 @@ match (char *str, char *sub)
 			}\
 		    }\
 		}
+
 #ifdef LOCALE
 #define PUTSF(cp, str, wid, fill) {\
 		ljust = 0;\
@@ -137,6 +141,7 @@ match (char *str, char *sub)
 		while( --i >= 0 && cp < ep)\
 		    *cp++ = fill;\
 	}
+
 #define PUTS(cp, str) {\
 		if ((sp = (str))) {\
 		    while ((c = (unsigned char) *sp) && (iscntrl(c) || isspace(c)))\
@@ -151,6 +156,7 @@ match (char *str, char *sub)
 			}\
 		}\
 	}
+
 #else /* LOCALE */
 #define PUTSF(cp, str, wid, fill) {\
 		ljust = 0;\
@@ -185,6 +191,7 @@ match (char *str, char *sub)
 		while( --i >= 0 && cp < ep)\
 		    *cp++ = fill;\
 		}
+
 #define PUTS(cp, str) {\
 		if (sp = (str)) {\
 		    while ((c = *sp) && c <= 32)\
@@ -199,7 +206,8 @@ match (char *str, char *sub)
 			}\
 		}\
 		}
-#endif
+
+#endif /* LOCALE */
 
 
 static char *lmonth[] = { "January",  "February","March",   "April",
@@ -255,7 +263,7 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 {
     char *cp, *ep, *sp;
     char *savestr, *str = NULL;
-    char buffer[BUFSIZ];
+    char buffer[BUFSIZ], buffer2[BUFSIZ];
     int i, c, ljust;
     int value = 0;
     time_t t;
@@ -417,13 +425,26 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	    if (!(str = getenv (fmt->f_text)))
 		str = "";
 	    break;
-	case FT_LS_MFIND:
+	case FT_LS_CFIND:
 	    if (!(str = context_find (fmt->f_text)))
 		str = "";
 	    break;
+
+	case FT_LS_DECODECOMP:
+	    if (decode_rfc2047(fmt->f_comp->c_text, buffer2))
+		str = buffer2;
+	    else
+		str = fmt->f_comp->c_text;
+	    break;
+
+	case FT_LS_DECODE:
+	    if (str && decode_rfc2047(str, buffer2))
+		str = buffer2;
+	    break;
+
 	case FT_LS_TRIM:
 	    if (str) {
-		    register char *xp;
+		    char *xp;
 
 		    strcpy(buffer, str);
 		    str = buffer;
@@ -689,12 +710,12 @@ fmt_scan (struct format *format, char *scanl, int width, int *dat)
 	     * (e.g., "To: ")
 	     */
 	    {
-	    register char *lp = str;
-	    register int indent;
-	    register int wid = value;
-	    register int len = strlen (str);
-	    register char *lastb;
+	    char *lp, *lastb;
+	    int indent, wid, len;
 
+	    lp = str;
+	    wid = value;
+	    len = strlen (str);
 	    sp = fmt->f_text;
 	    indent = strlen (sp);
 	    wid -= indent;
