@@ -46,11 +46,20 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	}
 
 	/*
-	 * See if we need more space.  If so, then allocate
-         * space for an addition 100 messages.
+	 * See if we need more space.  If we need space at the
+	 * end, then we allocate space for an addition 100 messages.
+	 * If we need space at the beginning of the range, then just
+	 * extend message status range to cover this message number.
          */
 	if (msgnum > mp->hghoff) {
-	    if ((mp = folder_realloc (mp, 0, msgnum + 100)))
+	    if ((mp = folder_realloc (mp, mp->lowoff, msgnum + 100)))
+		*mpp = mp;
+	    else {
+		advise (NULL, "unable to allocate folder storage");
+		return -1;
+	    }
+	} else if (msgnum < mp->lowoff) {
+	    if ((mp = folder_realloc (mp, msgnum, mp->hghoff)))
 		*mpp = mp;
 	    else {
 		advise (NULL, "unable to allocate folder storage");
