@@ -50,18 +50,18 @@ folder_delmsgs (struct msgs *mp, int rename_msgs)
 	vec[0] = r1bindex (rmmproc, '/');
 
 	switch (pid = vfork()) {
-	case NOTOK:
+	case -1:
 	    advise ("fork", "unable to");
-	    return NOTOK;
+	    return -1;
 
-	case OK:
+	case 0:
 	    execvp (rmmproc, vec);
 	    fprintf (stderr, "unable to exec ");
 	    perror (rmmproc);
 	    _exit (-1);
 
 	default:
-	    return (pidwait (pid, NOTOK));
+	    return (pidwait (pid, -1));
 	}
     }
 
@@ -72,13 +72,13 @@ folder_delmsgs (struct msgs *mp, int rename_msgs)
 	    if (rename_msgs) {
 		/* rename messages with standard prefix */
 		strcpy (buf, m_backup (dp));
-		if (rename (dp, buf) == NOTOK) {
+		if (rename (dp, buf) == -1) {
 		    admonish (buf, "unable to rename %s to", dp);
 		    retval = -1;
 		}
 	    } else {
 		/* or just unlink the selected messages */
-		if (unlink (dp) == NOTOK) {
+		if (unlink (dp) == -1) {
 		    admonish (dp, "unable to unlink");
 		    retval = -1;
 		}
