@@ -15,13 +15,17 @@
 int
 folder_pack (struct msgs **mpp, int verbose)
 {
-    register int hole, msgnum;
+    int hole, msgnum;
     char newmsg[BUFSIZ], oldmsg[BUFSIZ];
     struct msgs *mp;
 
     mp = *mpp;
 
-    if (mp->lowmsg > 1) {
+    /*
+     * Make sure we have message status space allocated
+     * for all numbers from 1 to current high message.
+     */
+    if (mp->lowoff > 1) {
 	if ((mp = folder_realloc (mp, 1, mp->hghmsg)))
 	    *mpp = mp;
 	else {
