@@ -79,9 +79,9 @@ folder_read (char *name)
 	    }
 
 	    /* Check if it is highest or lowest we've seen */
-	    if (mp->lowmsg == 0 || i < mp->lowmsg)
+	    if (mp->lowmsg == 0 || mp->lowmsg > i)
 		mp->lowmsg = i;
-	    if (i > mp->hghmsg)
+	    if (mp->hghmsg < i)
 		mp->hghmsg = i;
 
 	    /* Now record it in temporary place */
@@ -113,10 +113,10 @@ folder_read (char *name)
     mp->lowoff = max (mp->lowmsg, 1);
 
     /* Go ahead and allocate space for 100 additional messages. */
-    /* mp->hghoff = mp->hghmsg + 100; */
+    mp->hghoff = mp->hghmsg + 100;
 
     /* for testing, allocate minimal necessary space */
-    mp->hghoff = max (mp->hghmsg, 1);
+    /* mp->hghoff = max (mp->hghmsg, 1); */
 
     /*
      * Allocate space for status of each message.
