@@ -15,9 +15,9 @@ m_backup (char *file)
     static char buffer[BUFSIZ];
 
     if ((cp = r1bindex(file, '/')) == file)
-	sprintf(buffer, "%s%s", BACKUP_PREFIX, cp);
+	snprintf(buffer, BUFSIZ, "%s%s", BACKUP_PREFIX, cp);
     else
-	sprintf(buffer, "%.*s%s%s", cp - file, file, BACKUP_PREFIX, cp);
+	snprintf(buffer, BUFSIZ, "%.*s%s%s", cp - file, file, BACKUP_PREFIX, cp);
 
     unlink(buffer);
     return buffer;
