@@ -45,17 +45,17 @@ makedir (char *dir)
 		    *c = '/';
 	    }
  
-	    if (mkdir (dir, 0755) == NOTOK) {
+	    if (mkdir (dir, 0755) == -1) {
 		    advise (dir, "unable to create directory");
 		    return 0;
 	    }
     } else {
 	switch (pid = vfork()) {
-	case NOTOK: 
+	case -1: 
 	    advise ("fork", "unable to");
 	    return 0;
 
-	case OK: 
+	case 0: 
 	    setgid (getgid ());
 	    setuid (getuid ());
 
