@@ -15,7 +15,7 @@ seq_getnum (struct msgs *mp, char *seqname)
     int i;
 
     for (i = 0; mp->msgattrs[i]; i++)
-	if (strcmp (mp->msgattrs[i], seqname) == 0)
+	if (!strcmp (mp->msgattrs[i], seqname))
 	    return i;
 
     return -1;
