@@ -65,9 +65,13 @@ seq_list(struct msgs *mp, char *seqname)
 	 * 50 characters of the end.
 	 */
 	if (bp - buffer > len - 50) {
+	    char *newbuf;
+
 	    len += MAXBUFFER;
-	    if (!(buffer = realloc (buffer, (size_t) len)))
+	    if (!(newbuf = realloc (buffer, (size_t) len)))
 		adios (NULL, "unable to realloc storage in seq_list");
+	    bp = newbuf + (bp - buffer);
+	    buffer = newbuf;
 	}
 
 	/*
