@@ -13,7 +13,7 @@ seq_nameok (char *s)
 {
     char *pp;
 
-    if (!s || !*s) {
+    if (s == NULL || *s == '\0') {
 	advise (NULL, "empty sequence name");
 	return 0;
     }
@@ -22,15 +22,12 @@ seq_nameok (char *s)
      * Make sure sequence name doesn't clash with one
      * of the `reserved' sequence names.
      */
-    if (!(strcmp (s, "new")
-#if 0
-	    && strcmp (s, "cur")
-#endif
-	    && strcmp (s, "all")
-	    && strcmp (s, "first")
-	    && strcmp (s, "last")
-	    && strcmp (s, "prev")
-	    && strcmp (s, "next"))) {
+    if (!(strcmp (s, "new") &&
+	  strcmp (s, "all") &&
+	  strcmp (s, "first") &&
+	  strcmp (s, "last") &&
+	  strcmp (s, "prev") &&
+	  strcmp (s, "next"))) {
 	advise (NULL, "illegal sequence name: %s", s);
 	return 0;
     }
