@@ -18,14 +18,19 @@
 void
 seq_setprev (struct msgs *mp)
 {
-    register char *cp, *dp, **ap;
+    char **ap, *cp, *dp;
 
-    dp = NULL;
-    if ((cp = context_find (psequence)) == NULL
-	    || (ap = brkstring (dp = getcpy (cp), " ", "\n")) == NULL
-	    || *ap == NULL) {
-	if (dp)
+    /*
+     * Get the list of sequences for Previous-Sequence
+     * and split them.
+     */
+    if ((cp = context_find (psequence))) {
+	dp = getcpy (cp);
+	if (!(ap = brkstring (dp, " ", "\n")) || !*ap) {
 	    free (dp);
+	    return;
+	}
+    } else {
 	return;
     }
 
@@ -33,6 +38,5 @@ seq_setprev (struct msgs *mp)
     for (; *ap; ap++)
 	seq_addsel (mp, *ap, -1, 1);
 
-    if (dp)
-	free (dp);
+    free (dp);
 }
