@@ -26,14 +26,13 @@ showfile (char **arg, char *file)
     if (!strcmp (r1bindex (lproc, '/'), "mhl"))
 	lproc = mhlproc;
 
-    if ((pid = vfork()) == -1) {
+    switch (pid = vfork()) {
+    case -1:
 	/* fork error */
 	advise ("fork", "unable to");
 	return 1;
-    } else if (pid) {
-	/* parent */
-	return (pidwait (pid, NOTOK) & 0377 ? 1 : 0);
-    } else {
+
+    case 0:
 	/* child */
 	vecp = 0;
 	vec[vecp++] = r1bindex (lproc, '/');
@@ -56,6 +55,11 @@ showfile (char **arg, char *file)
 	fprintf (stderr, "unable to exec ");
 	perror (lproc);
 	_exit (-1);
+
+    default:
+	/* parent */
+	return (pidwait (pid, -1) & 0377 ? 1 : 0);
     }
+
     return 1;	/* NOT REACHED */
 }
