@@ -22,15 +22,16 @@ trimcpy (char *cp)
     /* start at the end and zap trailing whitespace */
     for (sp = cp + strlen(cp) - 1; sp >= cp; sp--) {
 	if (isspace(*sp))
-	    *sp = 0;
+	    *sp = '\0';
 	else
 	    break;
     }
 
     /* replace remaining whitespace with spaces */
-    for (sp = cp; *sp; sp++)
+    for (sp = cp; *sp; sp++) {
 	if (isspace(*sp))
 	    *sp = ' ';
+    }
 
     /* now return a copy */
     return getcpy(cp);
