@@ -14,7 +14,7 @@
 int
 uprf (char *c1, char *c2)
 {
-    register int c, mask;
+    int c, mask;
 
     if (!(c1 && c2))
 	return 0;
