@@ -1,6 +1,6 @@
 
 /*
- * ali.c -- list mail aliases
+ * ali.c -- list nmh mail aliases
  *
  * $Id$
  */
@@ -40,7 +40,7 @@ static struct swit switches[] = {
 
 static int pos = 1;
 
-extern struct aka  *akahead;
+extern struct aka *akahead;
 
 /*
  * prototypes
@@ -137,19 +137,27 @@ main (int argc, char **argv)
 	}
 	alias (AliasFile);
     }
-	
 
-    if (vecp)
-	for (i = 0; i < vecp; i++)
-	    if (inverted)
-		print_usr (vec[i], list, normalize);
-	    else
-		print_aka (akvalue (vec[i]), list, 0);
-    else {
-	if (inverted)
+    /*
+     * If -user is specified
+     */
+    if (inverted) {
+	if (vecp == 0)
 	    adios (NULL, "usage: %s -user addresses ...  (you forgot the addresses)",
 		   invo_name);
 
+	for (i = 0; i < vecp; i++)
+	    print_usr (vec[i], list, normalize);
+
+	done (0);
+    }
+
+    if (vecp) {
+	/* print specified aliases */
+	for (i = 0; i < vecp; i++)
+	    print_aka (akvalue (vec[i]), list, 0);
+    } else {
+	/* print them all */
 	for (ak = akahead; ak; ak = ak->ak_next) {
 	    printf ("%s: ", ak->ak_name);
 	    pos += strlen (ak->ak_name) + 1;
@@ -163,28 +171,29 @@ main (int argc, char **argv)
 void
 print_aka (char *p, int list, int margin)
 {
-    register char   c;
+    char c;
 
     if (p == NULL) {
 	printf ("<empty>\n");
 	return;
     }
 
-    while ((c = *p++))
+    while ((c = *p++)) {
 	switch (c) {
 	    case ',': 
-		if (*p)
+		if (*p) {
 		    if (list)
 			printf ("\n%*s", margin, "");
-		    else
+		    else {
 			if (pos >= 68) {
 			    printf (",\n ");
 			    pos = 2;
-			}
-			else {
+			} else {
 			    printf (", ");
 			    pos += 2;
 			}
+		    }
+		}
 
 	    case 0: 
 		break;
@@ -193,6 +202,7 @@ print_aka (char *p, int list, int margin)
 		pos++;
 		putchar (c);
 	}
+    }
 
     putchar ('\n');
     pos = 1;
@@ -232,12 +242,13 @@ print_usr (char *s, int list, int norm)
     }
     mnfree (mp);
 
-#ifdef	notdef
+#if 0
     printf ("%s: ", s);
     print_aka (vp ? vp : s, list, pos += strlen (s) + 1);
 #else
     print_aka (vp ? vp : s, list, 0);
 #endif
+
     if (vp)
 	free (vp);
 }
