@@ -210,7 +210,7 @@ main (int argc, char **argv)
 		case HELPSW: 
 		    sprintf (buffer, "%s [bboards ...] [switches] [switches for mshproc]",
 			invo_name);
-	    	    print_help (buffer, switches);
+	    	    print_help (buffer, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version (invo_name);
