@@ -83,7 +83,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buffer, "%s [+folder] [switches] bboard", invo_name);
-		    print_help (buffer, switches);
+		    print_help (buffer, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version (invo_name);
@@ -355,12 +355,12 @@ char   *folder,
 			state = m_getfld (state, name, buf, sizeof buf, fp);
 			hdrptr = add (buf, hdrptr);
 		    }
-		    if (uleq (name, "BBoard-ID")) {
+		    if (!strcasecmp (name, "BBoard-ID")) {
 			id = atoi (buf);
 			if (id > 0 && posted[0])
 			    break;
 		    }
-		    if (uleq (name, "BB-Posted")) {
+		    if (!strcasecmp (name, "BB-Posted")) {
 			strncpy (posted, buf, sizeof posted - 2);
 			if (posted[strlen (posted) - 1] == '\n')
 			    posted[strlen (posted) - 1] = NULL;
