@@ -72,7 +72,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -298,6 +298,14 @@ dumpone(struct format *fmt)
 		litputs(fmt->f_text);
 		break;
 
+	case FT_LS_DECODECOMP:
+		printf(", comp ");
+		litputs(fmt->f_comp->c_name);
+		break;
+
+	case FT_LS_DECODE:
+		break;
+
 	case FT_LS_TRIM:
 		printf(", width %d", fmt->f_width);
 		break;
@@ -349,6 +357,8 @@ f_typestr(int t)
 	case FT_LS_COMP: return("LS_COMP");
 	case FT_LS_LIT: return("LS_LIT");
 	case FT_LS_GETENV: return("LS_GETENV");
+	case FT_LS_DECODECOMP: return("FT_LS_DECODECOMP");
+	case FT_LS_DECODE: return("FT_LS_DECODE");
 	case FT_LS_TRIM: return("LS_TRIM");
 	case FT_LV_COMP: return("LV_COMP");
 	case FT_LV_COMPFLAG: return("LV_COMPFLAG");
