@@ -68,7 +68,7 @@ static struct swit switches[] = {
     { "changecur", 0 },
 #define	NCHGSW                     3
     { "nochangecur", 0 },
-#define	MSW                        4
+#define	FILESW                     4
     { "file name", 0 },
 #define	FORMSW                     5
     { "form formatfile", 0 },
@@ -260,18 +260,31 @@ main (int argc, char **argv)
 		chgflag = 0;
 		continue;
 
+	    /*
+	     * The flag `trnflag' has the value:
+	     *
+	     * 2 if -truncate is given
+	     * 1 by default (truncating is default)
+	     * 0 if -notruncate is given
+	     */
 	    case TRNCSW: 
-		trnflag++;
+		trnflag = 2;
 		continue;
 	    case NTRNCSW: 
 		trnflag = 0;
 		continue;
 
-	    case MSW: 
+	    case FILESW: 
 		if (!(cp = *argp++) || *cp == '-')
 		    adios (NULL, "missing argument to %s", argp[-2]);
 		from = path (cp, TFILE);
-		trnflag = 0;	/* don't truncate */
+
+		/*
+		 * If the truncate file is in default state,
+		 * change to not truncate.
+		 */
+		if (trnflag == 1)
+		    trnflag = 0;
 		continue;
 
 	    case SILSW: 
