@@ -8,6 +8,16 @@
 #include <h/mh.h>
 #include <pwd.h>
 
+static struct swit switches[] = {
+#define AUTOSW     0
+    { "auto", 0 },
+#define VERSIONSW  1
+    { "version", 0 },
+#define HELPSW     2
+    { "help", 4 },
+    { NULL, 0 }
+};
+
 static char *message[] = {
     "Prior to using nmh, it is necessary to have a file in your login",
     "directory (%s) named %s which contains information",
@@ -26,8 +36,10 @@ static char *geta(void);
 int
 main (int argc, char **argv)
 {
-    int i, autof;
+    int i, autof = 0;
     char *cp, *path;
+    char buf[100], *dp;
+    char *arguments[MAXARGS], **argp;
     struct node *np;
     struct passwd *pw;
     struct stat st;
@@ -37,8 +49,34 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
+    copyip (argv + 1, arguments);
+    argp = arguments;
 
-    autof = (argc == 2 && strcmp (argv[1], "-auto") == 0);
+    while ((dp = *argp++)) {
+	if (*dp == '-') {
+	    switch (smatch (++dp, switches)) {
+		case AMBIGSW:
+		    ambigsw (dp, switches);
+		    done (1);
+		case UNKWNSW:
+		    adios (NULL, "-%s unknown\n", dp);
+
+		case HELPSW:
+		    sprintf (buf, "%s [switches]", invo_name);
+		    print_help (buf, switches, 0);
+		    done (1);
+		case VERSIONSW:
+		    print_version(invo_name);
+		    done (1);
+
+		case AUTOSW:
+		    autof++;
+		    continue;
+	    }
+	} else {
+	    adios (NULL, "%s is invalid argument", dp);
+	}
+    }
 
     /* straight from context_read ... */
     if (mypath == NULL) {
