@@ -60,7 +60,7 @@ main(int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -103,12 +103,18 @@ main(int argc, char **argv)
 	adios (NULL, "unable to read folder %s", folder);
 
     /*
-     * We need to make sure there is message space for "new".
-     * If not, then go ahead and add space for another 100 messages.
+     * We need to make sure there is message status space
+     * for all the message numbers from 1 to "new" since
+     * mhpath can select empty slots.  If we are adding
+     * space at the end, we go ahead and add 10 slots.
      */
-    if ((mp->hghmsg >= mp->hghoff) &&
-	!(mp = folder_realloc (mp, 0, mp->hghmsg + 100)))
-	adios (NULL, "unable to allocate folder storage");
+    if (mp->hghmsg >= mp->hghoff) {
+	if (!(mp = folder_realloc (mp, 1, mp->hghmsg + 10)))
+	    adios (NULL, "unable to allocate folder storage");
+    } else if (mp->lowoff > 1) {
+	if (!(mp = folder_realloc (mp, 1, mp->hghoff)))
+	    adios (NULL, "unable to allocate folder storage");
+    }
 
     mp->msgflags |= ALLOW_NEW;	/* allow the "new" sequence */
 
