@@ -35,12 +35,6 @@
 #include <h/msh.h>
 #include <h/vmhsbr.h>
 
-#ifdef MIME
-# define MIMEminc(a) (a)
-#else
-# define MIMEminc(a)  0
-#endif
-
 #define	QUOTE	'\\'		/* sigh */
 
 static struct swit switches[] = {
@@ -273,7 +267,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] file", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -447,7 +441,7 @@ static struct swit mshcmds[] = {
 #define	MAILCMD	11
     { "mhmail", 0 },
 #define	MHNCMD	12
-    { "mhn", MIMEminc(-3) },
+    { "mhn", 0 },
 #define	MSGKCMD	13
     { "msgchk", 0 },
 #define	NEXTCMD	14
@@ -618,10 +612,8 @@ msh (int scansw)
 		break;
 
 	    case MHNCMD:
-#ifdef MIME
 		if (!vmh || ttyN (cmdp) != NOTOK)
 		    mhncmd (vec);
-#endif
 		break;
 
 	    case NEXTCMD: 
@@ -1103,7 +1095,7 @@ check_folder (int scansw)
     if (msgp <= mp->hghmsg)
 	return 0;		/* XXX */
 
-    if (!(mp = folder_realloc (mp, 0, msgp)))
+    if (!(mp = folder_realloc (mp, mp->lowoff, msgp)))
 	padios (NULL, "unable to allocate folder storage");
 
     low = mp->hghmsg + 1, hgh = msgp;
@@ -1225,7 +1217,7 @@ readid (int msgnum)
 	    case FLD: 
 	    case FLDEOF: 
 	    case FLDPLUS: 
-		if (uleq (name, BBoard_ID)) {
+		if (!strcasecmp (name, BBoard_ID)) {
 		    bp = getcpy (buf);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof buf, zp);
