@@ -123,7 +123,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -440,7 +440,7 @@ retr_action (char *rsp, int flag)
 	static char *cp;
 
 	if (flag == OK) {
-	    if (!(mp = folder_realloc (mp, 0, msgnum = mp->hghmsg + 1)))
+	    if (!(mp = folder_realloc (mp, mp->lowoff, msgnum = mp->hghmsg + 1)))
 		adios (NULL, "unable to allocate folder storage");
 
 	    cp = getcpy (m_name (mp->hghmsg + 1));
