@@ -67,7 +67,7 @@ main (int argc, char **argv)
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [switches for postproc] address ...",
 			    invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -197,7 +197,7 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 	    case FLDPLUS: 
 		if ((cptr = wantcomp[CHASH (name)]))
 		    do {
-			if (uleq (name, cptr->c_name)) {
+			if (!strcasecmp (name, cptr->c_name)) {
 			    char_read += msg_count;
 			    if (!cptr->c_text) {
 				cptr->c_text = tmpbuf;
