@@ -92,7 +92,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [msgs] [switches] +folder ...", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
