@@ -7,11 +7,6 @@
 
 #include <h/mh.h>
 
-#ifdef MIME
-# define MIMEminc(a)  0
-#else
-# define MIMEminc(a) (a)
-#endif
 
 static struct swit switches[] = {
 #define GROUPSW                0
@@ -51,9 +46,9 @@ static struct swit switches[] = {
 #define	NINPLSW               17
     { "noinplace", 0 },
 #define MIMESW                18
-    { "mime", MIMEminc(-4) },
+    { "mime", 0 },
 #define NMIMESW               19
-    { "nomime", MIMEminc(-6) },
+    { "nomime", 0 },
 #define	QURYSW                20
     { "query", 0 },
 #define	NQURYSW               21
@@ -175,7 +170,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s: [+folder] [msg] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (0);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -275,10 +270,8 @@ main (int argc, char **argv)
 		    continue;
 
 		case MIMESW:
-#ifdef MIME
 		    mime++;
 		    filter = NULL;
-#endif
 		    continue;
 		case NMIMESW:
 		    mime = 0;
