@@ -34,9 +34,12 @@ static void alert (char *, int);
 static int tmp_fd (void);
 static void anno (int, struct stat *);
 static void annoaux (int);
+static int splitmsg (char **, int, char *, struct stat *);
 static int sendaux (char **, int, char *, struct stat *);
-static int sendaux2 (char **, int, char *, struct stat *);
 
+/*
+ * prototypes
+ */
 int sendsbr (char **, int, char *, struct stat *);
 void done (int);
 char *getusr();
@@ -50,17 +53,29 @@ int
 sendsbr (char **vec, int vecp, char *drft, struct stat *st)
 {
     int status;
+    struct stat sts;
 
     armed++;
     switch (setjmp (env)) {
-	case OK: 
+    case OK: 
+	/*
+	 * Check if we need to split the message into
+	 * multiple messages of type "message/partial".
+	 */
+	if (splitsw >= 0 && !distfile && stat (drft, &sts) != NOTOK
+		&& sts.st_size >= CPERMSG) {
+	    status = splitmsg (vec, vecp, drft, st) ? NOTOK : OK;
+	} else {
+	    splitsw = -1;
 	    status = sendaux (vec, vecp, drft, st) ? NOTOK : OK;
-	    break;
+	}
+	break;
 
-	default: 
-	    status = DONE;
-	    break;
+    default: 
+	status = DONE;
+	break;
     }
+
     armed = 0;
     if (distfile)
 	unlink (distfile);
@@ -69,33 +84,28 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st)
 }
 
 
+/*
+ * Split large message into several messages of
+ * type "message/partial" and send them.
+ */
+
 static int
-sendaux (char **vec, int vecp, char *drft, struct stat *st)
+splitmsg (char **vec, int vecp, char *drft, struct stat *st)
 {
     int	compnum, nparts, partno, state, status;
     long pos, start;
     time_t clock;
     char *cp, *dp, buffer[BUFSIZ], msgid[BUFSIZ];
     char name[NAMESZ], partnum[BUFSIZ];
-    struct stat sts;
     FILE *in;
 
-    if (splitsw < 0
-	    || distfile
-	    || stat (drft, &sts) == NOTOK
-	    || sts.st_size < CPERMSG) {
-one_shot:
-	splitsw = -1;
-	return sendaux2 (vec, vecp, drft, st);
-    }
-
     if ((in = fopen (drft, "r")) == NULL)
 	adios (drft, "unable to open for reading");
 
     cp = dp = NULL;
     start = 0L;
     for (compnum = 1, state = FLD;;) {
-	switch (state = m_getfld (state, name, buffer, sizeof buffer, in)) {
+	switch (state = m_getfld (state, name, buffer, sizeof(buffer), in)) {
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
@@ -105,21 +115,21 @@ one_shot:
 		        || !strcasecmp (name, "Encrypted")
 		        || !strcasecmp (name, "Message-ID")) {
 		    while (state == FLDPLUS)
-			state = m_getfld (state, name, buffer, sizeof buffer,
+			state = m_getfld (state, name, buffer, sizeof(buffer),
 					  in);
 		} else {
 		    if (uprf (name, XXX_FIELD_PRF)) {
 			dp = add (concat (name, ":", buffer, NULL), dp);
 			while (state == FLDPLUS) {
 			    state = m_getfld (state, name, buffer,
-					      sizeof buffer, in);
+					      sizeof(buffer), in);
 			    dp = add (buffer, dp);
 			}
 		    } else {
 			cp = add (concat (name, ":", buffer, NULL), cp);
 			while (state == FLDPLUS) {
 			    state = m_getfld (state, name, buffer,
-					      sizeof buffer, in);
+					      sizeof(buffer), in);
 			    cp = add (buffer, cp);
 			}
 		    }
@@ -149,21 +159,26 @@ one_shot:
     if (cp == NULL)
 	adios (NULL, "headers missing from draft");
 
-    nparts = 1, pos = start;
-    while (fgets (buffer, sizeof buffer - 1, in)) {
+    nparts = 1;
+    pos = start;
+    while (fgets (buffer, sizeof(buffer) - 1, in)) {
 	long len;
 
-	if ((pos += (len = strlen (buffer))) > CPERMSG)
-	    nparts++, pos = len;
+	if ((pos += (len = strlen (buffer))) > CPERMSG) {
+	    nparts++;
+	    pos = len;
+	}
     }
+
+    /* Only one part, nothing to split */
     if (nparts == 1) {
 	free (cp);
 	if (dp)
 	    free (dp);
 
 	fclose (in);
-
-	goto one_shot;
+	splitsw = -1;
+	return sendaux (vec, vecp, drft, st);
     }
 
     if (!pushsw) {
@@ -210,7 +225,7 @@ one_shot:
 	for (;;) {
 	    long len;
 
-	    if (!fgets (buffer, sizeof buffer - 1, in)) {
+	    if (!fgets (buffer, sizeof(buffer) - 1, in)) {
 		if (partno == nparts)
 		    break;
 		adios (NULL, "premature eof");
@@ -244,7 +259,7 @@ one_shot:
 	}
 
 	sprintf (partnum, "%d", partno);
-	status = sendaux2 (vec, vecp, tmpdrf, st);
+	status = sendaux (vec, vecp, tmpdrf, st);
 	unlink (tmpdrf);
 	if (status != OK)
 	    break;
@@ -272,7 +287,7 @@ one_shot:
  */
 
 static int
-sendaux2 (char **vec, int vecp, char *drft, struct stat *st)
+sendaux (char **vec, int vecp, char *drft, struct stat *st)
 {
     pid_t child_id;
     int i, status, fd, fd2;
@@ -561,7 +576,7 @@ annoaux (int fd)
 	goto oops;
     }
     cp = NULL;
-    while (fgets (buffer, sizeof buffer, fp) != NULL)
+    while (fgets (buffer, sizeof(buffer), fp) != NULL)
 	cp = add (buffer, cp);
     fclose (fp);
 
@@ -578,7 +593,7 @@ annoaux (int fd)
 
     free (cp);
 
-oops: ;
+oops:
     folder_free (mp);	/* free folder/message structure */
 }
 
