@@ -6,38 +6,35 @@
  */
 
 #include <h/mh.h>
-
-#ifdef MIME
-# include <h/mhn.h>
-#endif
+#include <h/mhn.h>
 
 static struct swit switches[] = {
-#define	DRFTSW               0
-    { "draft", 0 },
-#define	FORMSW               1
-    { "form formfile", 0 },
-#define	PROGSW               2
-    { "moreproc program", 0 },
-#define	NPROGSW              3
-    { "nomoreproc", 0 },
-#define	LENSW                4
-    { "length lines", 0 },
-#define	WIDTHSW              5
-    { "width columns", 0 },
-#define	NSHOWSW              6
-    { "noshowproc", 0 },
-#define	SHOWSW               7
-    { "showproc program", 0 },
-#define SHOWMIMESW           8
-    { "showmimeproc program", 0 },
-#define CHECKMIMESW          9
+#define CHECKMIMESW          0
     { "checkmime", 0 },
-#define NOCHECKMIMESW       10
+#define NOCHECKMIMESW        1
     { "nocheckmime", 0 },
-#define	HEADSW              11
+#define	HEADSW               2
     { "header", 0 },
-#define	NHEADSW             12
+#define	NHEADSW              3
     { "noheader", 0 },
+#define	FORMSW               4
+    { "form formfile", 0 },
+#define	PROGSW               5
+    { "moreproc program", 0 },
+#define	NPROGSW              6
+    { "nomoreproc", 0 },
+#define	LENSW                7
+    { "length lines", 0 },
+#define	WIDTHSW              8
+    { "width columns", 0 },
+#define	SHOWSW               9
+    { "showproc program", 0 },
+#define SHOWMIMESW          10
+    { "showmimeproc program", 0 },
+#define	NSHOWSW             11
+    { "noshowproc", 0 },
+#define	DRFTSW              12
+    { "draft", 0 },
 #define	FILESW              13
     { "file file", -4 },		/* interface from showfile */
 #define VERSIONSW           14
@@ -50,9 +47,7 @@ static struct swit switches[] = {
 /*
  * static prototypes
  */
-#ifdef MIME
-static int is_mime(char *);
-#endif
+static int is_nontext(char *);
 
 #define	SHOW  0
 #define	NEXT  1
@@ -75,9 +70,9 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
 
-    if (uleq (invo_name, "next")) {
+    if (!strcasecmp (invo_name, "next")) {
 	mode = NEXT;
-    } else if (uleq (invo_name, "prev")) {
+    } else if (!strcasecmp (invo_name, "prev")) {
 	mode = PREV;
     }
 
@@ -104,7 +99,7 @@ main (int argc, char **argv)
 		case HELPSW: 
 		    sprintf (buf, "%s [+folder] %s[switches] [switches for showproc]",
 			    invo_name, mode == SHOW ? "[msgs] ": "");
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -281,18 +276,18 @@ go_to_it: ;
     if (nshow) {
 	proc = catproc;
     } else {
-	/* check if any messages are MIME */
+	/* check if any messages are non-text MIME messages */
 	if (checkmime && !getenv ("NOMHNPROC")) {
 	    if (!draftsw && !file) {
 		/* loop through selected messages and check for MIME */
 		for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		    if (is_selected (mp, msgnum) && is_mime (m_name (msgnum))) {
+		    if (is_selected (mp, msgnum) && is_nontext (m_name (msgnum))) {
 			mime = 1;
 			break;
 		    }
 	    } else {
 		/* check the file or draft for MIME */
-		if (is_mime (vec[vecp - 1]))
+		if (is_nontext (vec[vecp - 1]))
 		    mime = 1;
 	    }
 	}
@@ -366,93 +361,90 @@ OfficialName (char *name)
     return name;
 }
 
-#ifdef MIME
 
 /*
- * Check if a message or file is a MIME message
+ * Check if a message or file contains any non-text parts
  */
 static int
-is_mime (char *msgnam)
+is_nontext (char *msgnam)
 {
     int	result, state;
-    char *bp, *cp, *dp, *chset;
+    char *bp, *cp, *dp;
     char buf[BUFSIZ], name[NAMESZ];
     FILE *fp;
 
     if ((fp = fopen (msgnam, "r")) == NULL)
 	return 0;
 
-    if (!(chset = getenv ("MM_CHARSET")))
-	chset = "us-ascii";
-
-    for (state = FLD;;)
+    for (state = FLD;;) {
 	switch (state = m_getfld (state, name, buf, sizeof(buf), fp)) {
-	    case FLD:
-	    case FLDPLUS:
-	    case FLDEOF:
-		/*
-		 * Check Content-Type field
-		 */
-	        if (uleq (name, TYPE_FIELD)) {
-		    int	passno;
-		    char c;
+	case FLD:
+	case FLDPLUS:
+	case FLDEOF:
+	    /*
+	     * Check Content-Type field
+	     */
+	    if (!strcasecmp (name, TYPE_FIELD)) {
+		int passno;
+		char c;
 
-		    cp = add (buf, NULL);
-		    while (state == FLDPLUS) {
-			state = m_getfld (state, name, buf, sizeof(buf), fp);
-			cp = add (buf, cp);
-		    }
-		    bp = cp;
-		    passno = 1;
+		cp = add (buf, NULL);
+		while (state == FLDPLUS) {
+		    state = m_getfld (state, name, buf, sizeof(buf), fp);
+		    cp = add (buf, cp);
+		}
+		bp = cp;
+		passno = 1;
 
 again:
-		    for (; isspace (*bp); bp++)
-			continue;
-		    if (*bp == '(') {
-			int i;
+		for (; isspace (*bp); bp++)
+		    continue;
+		if (*bp == '(') {
+		    int i;
 
-			for (bp++, i = 0;;) {
-			    switch (*bp++) {
-				case '\0':
+		    for (bp++, i = 0;;) {
+			switch (*bp++) {
+			case '\0':
 invalid:
-				    result = 0;
-				    goto out;
-				case '\\':
-				    if (*bp++ == '\0')
-					goto invalid;
-    				    continue;
-				case '(':
-    				    i++;
-    				    /* and fall... */
-    				default:
-    				    continue;
-    				case ')':
-    				    if (--i < 0)
-					break;
-				continue;
-			    }
-			    break;
-			}
-		    }
-		    if (passno == 2) {
-			if (*bp != '/')
-			    goto invalid;
-			bp++;
-			passno = 3;
-			goto again;
-		    }
-		    for (dp = bp; istoken (*dp); dp++)
-			continue;
-		    c = *dp;
-		    *dp = '\0';
-		    if (!*bp)
-			goto invalid;
-		    if (passno > 1) {
-			if ((result = !uleq (bp, "plain")))
+			    result = 0;
 			    goto out;
-			*dp = c;
-			for (dp++; isspace (*dp); dp++)
+			case '\\':
+			    if (*bp++ == '\0')
+				goto invalid;
 			    continue;
+			case '(':
+			    i++;
+			    /* and fall... */
+			default:
+			    continue;
+			case ')':
+			    if (--i < 0)
+				break;
+			    continue;
+			}
+			break;
+		    }
+		}
+		if (passno == 2) {
+		    if (*bp != '/')
+			goto invalid;
+		    bp++;
+		    passno = 3;
+		    goto again;
+		}
+		for (dp = bp; istoken (*dp); dp++)
+		    continue;
+		c = *dp;
+		*dp = '\0';
+		if (!*bp)
+		    goto invalid;
+		if (passno > 1) {
+		    if ((result = (strcasecmp (bp, "plain") != 0)))
+			goto out;
+		    *dp = c;
+		    for (dp++; isspace (*dp); dp++)
+			continue;
+		    if (*dp) {
 			if ((result = !uprf (dp, "charset")))
 			    goto out;
 			dp += sizeof("charset") - 1;
@@ -472,69 +464,70 @@ invalid:
 				    break;
 				}
 			}
-			if ((result = !uleq (dp, chset))
-			        && uleq (dp, "us-ascii")
-			        && uleq (chset, "iso-8859-1"))
-			    result = 0;
 		    } else {
-			if (!(result = !uleq (bp, "text"))) {
-			    *dp = c;
-			    bp = dp;
-			    passno = 2;
-			    goto again;
-			}
+			/* Default character set */
+			dp = "US-ASCII";
 		    }
-
+		    /* Check the character set */
+		    result = !check_charset (dp, strlen (dp));
+		} else {
+		    if (!(result = (strcasecmp (bp, "text") != 0))) {
+			*dp = c;
+			bp = dp;
+			passno = 2;
+			goto again;
+		    }
+		}
 out:
-		    free (cp);
-		    if (result) {
-			fclose (fp);
-			return result;
-		    }
-		    break;
+		free (cp);
+		if (result) {
+		    fclose (fp);
+		    return result;
 		}
-
-		/*
-		 * Check Content-Transfer-Encoding field
-		 */
-	        if (uleq (name, ENCODING_FIELD)) {
-		    cp = add (buf, NULL);
-		    while (state == FLDPLUS) {
-			state = m_getfld (state, name, buf, sizeof(buf), fp);
-			cp = add (buf, cp);
-		    }
-		    for (bp = cp; isspace (*bp); bp++)
-			continue;
-		    for (dp = bp; istoken (*dp); dp++)
-			continue;
-		    *dp = '\0';
-		    result = !uleq (bp, "7bit")
-				&& !uleq (bp, "8bit")
-				&& !uleq (bp, "binary");
-
-		    free (cp);
-		    if (result) {
-			fclose (fp);
-			return result;
-		    }
-		    break;
-		}
-
-		/*
-		 * Just skip the rest of this header
-		 * field on go to next one.
-		 */
-		while (state == FLDPLUS)
-		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		break;
+	    }
+
+	    /*
+	     * Check Content-Transfer-Encoding field
+	     */
+	    if (!strcasecmp (name, ENCODING_FIELD)) {
+		cp = add (buf, NULL);
+		while (state == FLDPLUS) {
+		    state = m_getfld (state, name, buf, sizeof(buf), fp);
+		    cp = add (buf, cp);
+		}
+		for (bp = cp; isspace (*bp); bp++)
+		    continue;
+		for (dp = bp; istoken (*dp); dp++)
+		    continue;
+		*dp = '\0';
+		result = (strcasecmp (bp, "7bit")
+		       && strcasecmp (bp, "8bit")
+		       && strcasecmp (bp, "binary"));
+
+		free (cp);
+		if (result) {
+		    fclose (fp);
+		    return result;
+		}
+		break;
+	    }
+
+	    /*
+	     * Just skip the rest of this header
+	     * field and go to next one.
+	     */
+	    while (state == FLDPLUS)
+		state = m_getfld (state, name, buf, sizeof(buf), fp);
+	    break;
 
 	    /*
 	     * We've passed the message header,
-	     * so message is not MIME.
+	     * so message is just text.
 	     */
-	    default:
-		fclose (fp);
-		return 0;
+	default:
+	    fclose (fp);
+	    return 0;
 	}
+    }
 }
-#endif /* MIME */
