@@ -196,7 +196,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [address info sender]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 0);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -467,7 +467,7 @@ usr_delivery (int fd, char *delivery, int su)
 	string = vec[4];
 
 	if (vecp > 5) {
-	    if (uleq (vec[5], "select")) {
+	    if (!strcasecmp (vec[5], "select")) {
 		if (logged_in () != -1)
 		    continue;
 		if (vecp > 7 && timely (vec[6], vec[7]) == -1)
@@ -480,7 +480,7 @@ usr_delivery (int fd, char *delivery, int su)
 		break;
 
 	    case 'd': 
-		if (uleq (field, "default")) {
+		if (!strcasecmp (field, "default")) {
 		    if (won)
 			continue;
 		    break;
@@ -505,7 +505,7 @@ usr_delivery (int fd, char *delivery, int su)
 	switch (*action) {
 	    case 'q':
 		/* deliver to quoted pipe */
-		if (!uleq (action, "qpipe"))
+		if (strcasecmp (action, "qpipe"))
 		    continue;	/* else fall */
 	    case '^':
 		expand (tmpbuf, string, fd);
@@ -516,7 +516,7 @@ usr_delivery (int fd, char *delivery, int su)
 
 	    case 'p': 
 		/* deliver to pipe */
-		if (!uleq (action, "pipe"))
+		if (strcasecmp (action, "pipe"))
 		    continue;	/* else fall */
 	    case '|': 
 		vec[2] = "sh";
@@ -529,12 +529,12 @@ usr_delivery (int fd, char *delivery, int su)
 
 	    case 'f': 
 		/* mbox format */
-		if (uleq (action, "file")) {
+		if (!strcasecmp (action, "file")) {
 		    status = usr_file (fd, string, MBOX_FORMAT);
 		    break;
 		}
 		/* deliver to folder */
-		else if (!uleq (action, "folder"))
+		else if (strcasecmp (action, "folder"))
 		    continue;	/* else fall */
 	    case '+':
 		if (*string == '+')
@@ -551,12 +551,12 @@ usr_delivery (int fd, char *delivery, int su)
 
 	    case 'm':
 		/* mmdf format */
-		if (uleq (action, "mmdf")) {
+		if (!strcasecmp (action, "mmdf")) {
 		    status = usr_file (fd, string, MMDF_FORMAT);
 		    break;
 		}
 		/* mbox format */
-		else if (!uleq (action, "mbox"))
+		else if (strcasecmp (action, "mbox"))
 		    continue;	/* else fall */
 
 	    case '>': 
@@ -565,7 +565,7 @@ usr_delivery (int fd, char *delivery, int su)
 		break;
 
 	    case 'd': 
-		if (!uleq (action, "destroy"))
+		if (strcasecmp (action, "destroy"))
 		    continue;
 		status = 0;
 		break;
@@ -657,7 +657,7 @@ parse (int fd)
 		    lp = add (field, lp);
 		}
 		for (p = hdrs; p->p_name; p++)
-		    if (uleq (p->p_name, name)) {
+		    if (!strcasecmp (p->p_name, name)) {
 			if (!(p->p_flags & P_HID)) {
 			    if ((cp = p->p_value))
 				if (p->p_flags & P_ADR) {
@@ -788,7 +788,7 @@ static struct pair *
 lookup (struct pair *pairs, char *key)
 {
     for (; pairs->p_name; pairs++)
-	if (uleq (pairs->p_name, key))
+	if (!strcasecmp (pairs->p_name, key))
 	    return pairs;
 
     return NULL;
@@ -1317,7 +1317,8 @@ suppress_duplicates (int fd, char *file)
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
-		if (!uleq (name, "Message-ID")) {
+		/* Search for the message ID */
+		if (strcasecmp (name, "Message-ID")) {
 		    while (state == FLDPLUS)
 			state = m_getfld (state, name, buf, sizeof(buf), in);
 		    continue;
