@@ -95,7 +95,7 @@ main (int argc, char **argv)
 
 	    case HELPSW:
 		sprintf(buf, "%s [+folder] [msgs] [switches]", invo_name);
-		print_help (buf, switches);
+		print_help (buf, switches, 1);
 		done (1);
 	    case VERSIONSW:
 		print_version(invo_name);
@@ -326,7 +326,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 	case FLDEOF:
 	case FLDPLUS:
 	    compnum++;
-	    if (uleq (nam, datesw)) {
+	    if (!strcasecmp (nam, datesw)) {
 		datecomp = add (buf, datecomp);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, nam, buf, sizeof buf, in);
@@ -334,7 +334,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 		}
 		if (!subjsort || subjcomp)
 		    break;
-	    } else if (subjsort && uleq (nam, subjsort)) {
+	    } else if (subjsort && !strcasecmp (nam, subjsort)) {
 		subjcomp = add (buf, subjcomp);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, nam, buf, sizeof buf, in);
