@@ -18,8 +18,7 @@
  * delivery to a ZOTnet BBoard and/or addition re-distribution to other
  * recipients of the BBoard.  This program can function both as a SendMail
  * mailer and an MH .mh_receive file, depending on whether SENDMTS or
- * MHMTS is set.  Currently, the MHMTS version of this program does not do
- * re-distribution.
+ * MHMTS is set.
  *
  * This program should be used ONLY if you have "bboards on" set in your
  * MH configuration, and if you have "mts sendmail" or "mts mh" set as well.
@@ -41,7 +40,7 @@
 #ifdef SENDMTS
 # ifndef SPOP
 #  define DISTRIBUTE
-# endif	not SPOP
+# endif	/* not SPOP */
 #endif SENDMTS
 
 #include <pwd.h>
@@ -70,7 +69,7 @@
 #endif
 
 #ifdef DISTRIBUTE
-# include <mts/sendmail/smail.h>
+# include <mts/smtp/smtp.h>
 #endif
 
 #define	NBB	100
@@ -125,10 +124,6 @@ main (int argc, char **argv, char **envp)
 #ifdef LOCALE
     setlocale(LC_ALL, "");
 #endif
-#ifdef	MHMTS
-    if (argc != 5)
-	adios (EX_USAGE, NULL, "you lose really big");
-#endif	MHMTS
     arginit (argv);
 
     fflush (stdout);
@@ -490,12 +485,13 @@ arginit (char **vec)
     char addr[BUFSIZ];
     register struct bboard *bp;
     register struct passwd *pw;
-#ifdef	MHMTS
-    register char *ap;
-#endif	MHMTS
 
     invo_name = r1bindex (*vec++, '/');
-    m_foil (NULL);		/* foil search of user profile */
+
+    /* foil search of user profile/context */
+    if (context_foil (NULL) == -1)
+	done (1);
+
     mts_init (invo_name);
 
 #ifndef	SPOP
@@ -520,18 +516,11 @@ arginit (char **vec)
     strcpy (bb_home, pw->pw_dir);
 #endif	not SPOP
 
-#ifdef	MHMTS
-    vec += 3;
-#endif	MHMTS
     if (*vec == NULL)
 	adios (EX_USAGE, NULL, "usage: %s %s [%s ...]",
 		invo_name, ENTITY, ENTITY);
 
     for (i = 0; *vec; vec++) {
-#ifdef	MHMTS
-	if (ap = strchr (*vec, '.'))
-	    *vec = ++ap;
-#endif	MHMTS
 	make_lower (addr, *vec);
 
 	if ((bp = getbbnam (addr)) == NULL
@@ -589,7 +578,4 @@ adios (int code, char *what, char *fmt, ...)
 #ifdef SENDMTS
     done (code);
 #endif
-#ifdef MHMTS
-    done (1);
-#endif
 }
