@@ -222,7 +222,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] file", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -577,7 +577,7 @@ get_header (char *header, struct headers *table)
     struct headers *h;
 
     for (h = table; h->value; h++)
-	if (uleq (header, h->value))
+	if (!strcasecmp (header, h->value))
 	    return (h - table);
 
     return NOTOK;
