@@ -8,16 +8,7 @@
 #include <h/mh.h>
 #include <fcntl.h>
 #include <signal.h>
-
-#ifdef MIME
 #include <h/mhn.h>
-#endif
-
-#ifndef MIME
-# define MIMEminc(a) (a)
-#else
-# define MIMEminc(a)  0
-#endif
 
 static struct swit whatnowswitches[] = {
 #define	DFOLDSW                 0
@@ -74,15 +65,12 @@ static int sendfile (char **, char *, int);
 static void sendit (char *, char **, char *, int);
 static int build_mime (char **, char *);
 static int whomfile (char **, char *);
+static int check_draft (char *);
 
 #ifdef HAVE_LSTAT
 static int copyf (char *, char *);
 #endif
 
-#ifdef MIME
-static int mhnfile (char *);
-#endif
-
 
 int
 WhatNow (int argc, char **argv)
@@ -106,7 +94,7 @@ WhatNow (int argc, char **argv)
 
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, whatnowswitches)) {
 	    case AMBIGSW: 
 		ambigsw (cp, whatnowswitches);
@@ -116,7 +104,7 @@ WhatNow (int argc, char **argv)
 
 	    case HELPSW: 
 		sprintf (buf, "%s [switches] [file]", invo_name);
-		print_help (buf, whatnowswitches);
+		print_help (buf, whatnowswitches, 1);
 		done (1);
 	    case VERSIONSW:
 		print_version(invo_name);
@@ -155,6 +143,7 @@ WhatNow (int argc, char **argv)
 		    adios (NULL, "missing argument to %s", argp[-2]);
 		continue;
 	    }
+	}
 	if (drft)
 	    adios (NULL, "only one draft at a time!");
 	else
@@ -449,22 +438,20 @@ sendfile (char **arg, char *file, int pushsw)
     int i, vecp;
     char *cp, *sp, *vec[MAXARGS];
 
-#ifdef MIME
     /* Translate MIME composition file, if necessary */
     if ((cp = context_find ("automimeproc"))
-	    && (uleq (cp, "1"))
+	    && (!strcmp (cp, "1"))
 	    && !getenv ("NOMHNPROC")
-	    && mhnfile (file)
+	    && check_draft (file)
 	    && (build_mime (NULL, file) == NOTOK))
 	return 0;
 
     /* For backwards compatibility */
     if ((cp = context_find ("automhnproc"))
 	    && !getenv ("NOMHNPROC")
-	    && mhnfile (file)
+	    && check_draft (file)
 	    && (i = editfile (&cp, NULL, file, NOUSE, NULL, NULL, NULL)))
 	return 0;
-#endif
 
     /*
      * If the sendproc is the nmh command `send', then we call
@@ -510,7 +497,7 @@ sendfile (char **arg, char *file, int pushsw)
 
 
 /*
- * Translate MIME composition file
+ * Translate MIME composition file (call buildmimeproc)
  */
 
 static int
@@ -530,7 +517,10 @@ build_mime (char **argp, char *file)
     if ((args = (char **) malloc((i + 2) * sizeof(char *))) == NULL)
 	adios (NULL, "unable to malloc memory");
 
-    /* need to add -build if using mhn as buildmimeproc */
+    /*
+     * For backward compatibility, we need to add -build
+     * if we are using mhn as buildmimeproc
+     */
     i = 0;
     if (strcmp (r1bindex (ed, '/'), "mhn") == 0)
 	args[i++] = "-build";
@@ -549,14 +539,13 @@ build_mime (char **argp, char *file)
 	return OK;
 }
 
-#ifdef MIME
 
 /*
- *  Check if draft is a mhn composition file
+ *  Check if draft is a mhbuild composition file
  */
 
 static int
-mhnfile (char *msgnam)
+check_draft (char *msgnam)
 {
     int	state;
     char buf[BUFSIZ], name[NAMESZ];
@@ -602,8 +591,6 @@ mhnfile (char *msgnam)
 	}
 }
 
-#endif /* MIME */
-
 
 static struct swit  sendswitches[] = {
 #define	ALIASW            0
@@ -622,27 +609,27 @@ static struct swit  sendswitches[] = {
     { "forward", 0 },
 #define	NFORWSW           7
     { "noforward", 0 },
-#define	MIMESW            8
-    { "mime", MIMEminc(-4) },
-#define	NMIMESW           9
-    { "nomime", MIMEminc(-6) },
-#define	MSGDSW           10
+#define MIMESW            8
+    { "mime", 0 },
+#define NMIMESW           9
+    { "nomime", 0 },
+#define MSGDSW           10
     { "msgid", 0 },
-#define	NMSGDSW          11
+#define NMSGDSW          11
     { "nomsgid", 0 },
-#define	SPSHSW           12
+#define SPSHSW           12
     { "push", 0 },
-#define	NSPSHSW          13
+#define NSPSHSW          13
     { "nopush", 0 },
-#define	SPLITSW          14
-    { "split seconds", MIMEminc(-5) },
-#define	UNIQSW           15
+#define SPLITSW          14
+    { "split seconds", 0 },
+#define UNIQSW           15
     { "unique", -6 },
-#define	NUNIQSW          16
+#define NUNIQSW          16
     { "nounique", -8 },
-#define	VERBSW           17
+#define VERBSW           17
     { "verbose", 0 },
-#define	NVERBSW          18
+#define NVERBSW          18
     { "noverbose", 0 },
 #define	WATCSW           19
     { "watch", 0 },
@@ -742,7 +729,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 
 		case SHELPSW: 
 		    sprintf (buf, "%s [switches]", sp);
-		    print_help (buf, sendswitches);
+		    print_help (buf, sendswitches, 1);
 		    return;
 		case SVERSIONSW:
 		    print_version (invo_name);
