@@ -445,7 +445,7 @@ BBread (void)
 	bb->bb_maxima = (unsigned) i;
     if (!feof (info) && fgets (line, sizeof line, info)) {
 	strcpy (BBDate, line);
-	if (cp = strchr(BBDate, NEWLINE))
+	if ((cp = strchr(BBDate, NEWLINE)))
 	    *cp = 0;
 	bb->bb_date = BBDate;
     }
@@ -480,14 +480,14 @@ ldrbb (struct bboard *b)
 	return 1;
 
     q = b->bb_leader;
-    while (p = *q++)
+    while ((p = *q++))
 	if (*p == '=') {
 	    if ((gr = getgrnam (++p)) == NULL)
 		continue;
 	    if (gid == gr->gr_gid)
 		return 1;
 	    r = gr->gr_mem;
-	    while (p = *r++)
+	    while ((p = *r++))
 		if (strcmp (username, p) == 0)
 		    return 1;
 	}
@@ -590,7 +590,7 @@ getbbdist (struct bboard  *bb, int (*action)())
 
     BBErrors[0] = 0;
     for (dp = bb->bb_dist; *dp; dp++)
-	if (result = getbbitem (bb, *dp, action))
+	if ((result = getbbitem (bb, *dp, action)))
 	    return result;
 
     return result;
@@ -642,9 +642,9 @@ getbbitem (struct bboard *bb, char *item, int (*action)())
 	    if ((fp = fopen (hp, "r")) == NULL)
 		return bblose ("unable to read file %s", hp);
 	    while (fgets (buffer, sizeof buffer, fp)) {
-		if (np = strchr(buffer, '\n'))
+		if ((np = strchr(buffer, '\n')))
 		    *np = 0;
-		if (result = getbbitem (bb, buffer, action)) {
+		if ((result = getbbitem (bb, buffer, action))) {
 		    fclose (fp);
 		    bblose ("error with file %s, item %s", hp, buffer);
 		    return result;
@@ -654,7 +654,7 @@ getbbitem (struct bboard *bb, char *item, int (*action)())
 	    return OK;
 
 	default: 
-	    if (hp = strrchr(item, '@')) {
+	    if ((hp = strrchr(item, '@'))) {
 		*hp++ = 0;
 		strcpy (mbox, item);
 		strcpy (host, hp);
@@ -664,7 +664,7 @@ getbbitem (struct bboard *bb, char *item, int (*action)())
 		sprintf (mbox, "%s%s", DISTADR, bb->bb_name);
 		strcpy (host, item);
 	    }
-	    if (result = (*action) (mbox, host))
+	    if ((result = (*action) (mbox, host)))
 		bblose ("action (%s, %s) returned 0%o", mbox, host, result);
 	    return result;
     }
@@ -722,7 +722,7 @@ getcpy (char *s)
 	return NULL;
 
     len = strlen (s) + 1;
-    if (p = malloc (len))
+    if ((p = malloc (len)))
 	memcpy (p, s, len);
     return p;
 }
