@@ -68,7 +68,7 @@ char *PrincipalHostname();
 #endif
 
 #define	inaddr_copy(hp,sin) \
-    memcpy((char *) &((sin)->sin_addr), (hp)->h_addr, (hp)->h_length)
+    memcpy(&((sin)->sin_addr), (hp)->h_addr, (hp)->h_length)
 
 /*
  * static prototypes
@@ -209,7 +209,7 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto, char *response)
     if ((sd = getport (rproto, hp->h_addrtype, response)) == NOTOK)
 	return OOPS2;
 
-    memset((char *) isock, 0, sizeof(*isock));
+    memset(isock, 0, sizeof(*isock));
     isock->sin_family = hp->h_addrtype;
     inaddr_copy (hp, isock);
     isock->sin_port = sp->s_port;
@@ -221,7 +221,7 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto, char *response)
 		close (sd);
 		if (n1 < n2) {
 		    n1->a_addrtype = hp->h_addrtype;
-		    memcpy((char *) &in, hp->h_addr, sizeof(in));
+		    memcpy(&in, hp->h_addr, sizeof(in));
 		    n1->a_net = inet_netof (in);
 		    n1++;
 		}
@@ -290,10 +290,10 @@ getport (int rproto, int addrtype, char *response)
     if (!rproto)
 	return sd;
 
-    memset((char *) isock, 0, sizeof(*isock));
+    memset(isock, 0, sizeof(*isock));
     isock->sin_family = addrtype;
     for (port = IPPORT_RESERVED - 1;;) {
-	isock->sin_port = htons ((ushort) port);
+	isock->sin_port = htons ((unsigned short) port);
 	if (bind (sd, (struct sockaddr *) isock, sizeof(*isock)) != NOTOK)
 	    return sd;
 
@@ -324,12 +324,14 @@ inet (struct hostent *hp, int net)
 {
     struct in_addr in;
 
-    memcpy((char *) &in, hp->h_addr, sizeof(in));
+    memcpy(&in, hp->h_addr, sizeof(in));
     return (inet_netof (in) == net);
 }
 
 
-/* taken from ISODE's compat/internet.c */
+/*
+ * taken from ISODE's compat/internet.c
+ */
 
 static char *empty = NULL;
 
@@ -345,7 +347,7 @@ gethostbystring (char *s)
 #ifdef DG
     static struct in_addr iaddr;
 #else
-    static ulong iaddr;
+    static unsigned long iaddr;
 #endif
 
     iaddr = inet_addr (s);
@@ -363,7 +365,7 @@ gethostbystring (char *s)
     h->h_length = sizeof(iaddr);
 #ifdef h_addr
     h->h_addr_list = addrs;
-    memset((char *) addrs, 0, sizeof(addrs));
+    memset(addrs, 0, sizeof(addrs));
 #endif
     h->h_addr = (char *) &iaddr;
 
