@@ -350,21 +350,24 @@ getusr (void)
     }
 
     np = pw->pw_gecos;
+
 #ifndef	GCOS_HACK
     for (cp = fullname; *np && *np != (MMailids ? '<' : ','); *cp++ = *np++)
 	continue;
 #else
-    for (cp = fullname; *np && *np != (MMailids ? '<' : ','); )
+    for (cp = fullname; *np && *np != (MMailids ? '<' : ','); ) {
 	if (*np == '&')	{	/* blech! */
 	    strcpy(cp, pw->pw_name);
 	    *cp = toupper(*cp);
 	    while (*cp)
 		cp++;
 	    np++;
-	}
-	else
+	} else {
 	    *cp++ = *np++;
+	}
+    }
 #endif
+
     *cp = '\0';
     if (MMailids) {
 	if (*np)
@@ -398,4 +401,3 @@ getfullname (void)
 
     return fullname;
 }
-
