@@ -41,14 +41,6 @@ extern char *mmdlm2;
  */
 void mts_init (char *);
 
-/*
- * locking prototypes
- */
-int lkopen(char *, int);
-int lkclose(int, char*);
-FILE *lkfopen(char *, char *);
-int lkfclose(FILE *, char *);
-
 /*
  * MTS specific variables
  */
